@@ -6,10 +6,10 @@ from .awyes import Deployment
 class DeploymentTestSuccess(unittest.TestCase):
     def __init__(self, *args, **kwargs):
         super(DeploymentTestSuccess, self).__init__(*args, **kwargs)
-        self.good_yaml = yaml.safe_load("./test_data/good.yml")
+        self.good_yaml = yaml.safe_load("./awyes/test_data/good.yml")
 
-    def test_ordering(self):
-        d = Deployment(path="./test_data/good.yml")
+    def test_ordering_and_populated_fields(self):
+        d = Deployment(path="./awyes/test_data/good.yml")
         sorted_nodes = d.get_topologically_sorted_nodes()
         self.assertEqual(sorted_nodes, [
             {
